@@ -13,7 +13,8 @@
 #define READ 0
 #define WRITE 1
 
-#undef TRACE_GDB
+#define TRACE_GDB
+static FILE* trace_fp = NULL;
 
 static void input_callback (GdbInstance *inst,
                             gint source,
@@ -118,7 +119,7 @@ gdb_clear_command_queue (GdbInstance *inst)
     while (cmd != NULL) {
 	cmd_prev = cmd;
 	cmd = cmd->next;
-                
+	
 	g_free (cmd_prev);
     }
         
@@ -160,7 +161,10 @@ gdb_read_line (GdbInstance *inst)
     buf[strlen (buf) - 1] = '\0';
   
 #ifdef TRACE_GDB
-    fprintf (stderr, "%s\n", buf);
+    if (!trace_fp)
+	trace_fp = fopen ("/home/dave/gdf.log", "w");
+    
+    fprintf (trace_fp, "%s\n", buf);
 #endif
         
     return buf;
@@ -234,7 +238,10 @@ execute_command (GdbInstance *inst)
     fflush (inst->proc->outputfp);
 
 #ifdef TRACE_GDB
-    fprintf (stderr, "%s\n", inst->first_command->command);
+    if (!trace_fp)
+	trace_fp = fopen ("/home/dave/gdf.log", "w");
+
+    fprintf (trace_fp, "%s\n", inst->first_command->command);
 #endif
 
     line = gdb_read_line (inst);
