@@ -14,6 +14,8 @@
 
 #include "gdb-signal.h"
 
+char *e_strdup_strip (char *string);
+
 /* An instance of gdb */
 struct _GdbInstance {
     ChildProcess *proc;
@@ -45,5 +47,6 @@ struct _GdbInstance {
 GdbInstance *gdb_create_instance (void);
 void gdb_destroy_instance (GdbInstance *inst);
 void gdb_emit_error (GdbInstance *inst, gchar *error_msg);
+gboolean gdb_set_working_directory (GdbInstance *inst, const char *dirname);
 
 #endif
