@@ -30,7 +30,7 @@ struct _GdbFrame {
 	char *function;
 	char *file;
 	int line_num;
-	void *addr;
+	long addr;
 };
 
 GList *gdb_get_stack (GdbInstance *inst);
