@@ -30,24 +30,24 @@
 #define NUM_SLICES 10
 
 static void update_symbol (GdbInstance *inst, GdfLibdryadSymbolSet *ss, 
-			   GDF_Symbol *sym);
-static void read_type (GdbInstance *inst, GDF_Symbol *sym);
-static void read_value (GdbInstance *inst, GDF_Symbol *sym);
+			   GNOME_Development_Symbol *sym);
+static void read_type (GdbInstance *inst, GNOME_Development_Symbol *sym);
+static void read_value (GdbInstance *inst, GNOME_Development_Symbol *sym);
 static void expand_pointer (GdbInstance *inst, GdfLibdryadSymbolSet *ss,
-			    GDF_Symbol *sym);
+			    GNOME_Development_Symbol *sym);
 static void expand_structure (GdbInstance *inst, GdfLibdryadSymbolSet *ss, 
-			      GDF_Symbol *sym);
+			      GNOME_Development_Symbol *sym);
 static void expand_array (GdbInstance *inst, GdfLibdryadSymbolSet *ss, 
-			  GDF_Symbol *sym);
+			  GNOME_Development_Symbol *sym);
 static void expand_array_slice (GdbInstance *inst, GdfLibdryadSymbolSet *ss, 
-				GDF_Symbol *sym);
+				GNOME_Development_Symbol *sym);
 static void add_slice (GdbInstance *inst, GdfLibdryadSymbolSet *ss, 
-		       GDF_Symbol *sym, unsigned begin, unsigned size);
+		       GNOME_Development_Symbol *sym, unsigned begin, unsigned size);
 static void expand_slice (GdbInstance *inst, GdfLibdryadSymbolSet *ss, 
-			  GDF_Symbol *sym, unsigned start, unsigned num);
-static void destroy_children (GDF_Symbol *sym);
-static GDF_SymbolSequence *init_seq (void);
-static void grow_seq (GDF_SymbolSequence *seq, int amount);
+			  GNOME_Development_Symbol *sym, unsigned start, unsigned num);
+static void destroy_children (GNOME_Development_Symbol *sym);
+static GNOME_Development_SymbolSequence *init_seq (void);
+static void grow_seq (GNOME_Development_SymbolSequence *seq, int amount);
 
 void
 gdb_get_locals (GdbInstance *inst, GdfLibdryadSymbolSet *ss)
@@ -67,36 +67,39 @@ gdb_get_locals (GdbInstance *inst, GdfLibdryadSymbolSet *ss)
 
     /* Look for the scope header */
     line = gdb_read_line (inst);
-    while (strncmp (line, "Scope for *($pc)", strlen ("Scope for *($pc)")))
+    while (strncmp (line, "Scope for *($pc)", 16)
+	   && strcmp (line, "\32\32error-begin"))
 	line = gdb_read_line (inst);
 
-    /* read all the variables in the scope */
-    line = gdb_read_line (inst);
-    while (!isspace (line[0]) && line[0] != '\0') {
-	line += strlen ("Symbol ");
-	work = line;
-	while (!isspace (*work++))
-	    ;
-	*(work - 1) = '\0';
-	names = g_list_prepend (names, g_strdup (line));
+    if (strcmp (line, "\32\32error-begin")) {
+	/* read all the variables in the scope */
 	line = gdb_read_line (inst);
+	while (!isspace (line[0]) && line[0] != '\0') {
+	    line += strlen ("Symbol ");
+	    work = line;
+	    while (!isspace (*work++))
+		;
+	    *(work - 1) = '\0';
+	    names = g_list_prepend (names, g_strdup (line));
+	    line = gdb_read_line (inst);
+	}
+	
+	/* Add all the locals to the symbol set */
+	names = g_list_reverse (names);
+	
+	for (i = names; i != NULL; i = i->next) {
+	    gdb_add_expression (inst, ss, i->data);
+	    g_free (i->data);
+	}
+	g_list_free (names);
     }
 
-    /* Add all the locals to the symbol set */
-    names = g_list_reverse (names);
-
-    for (i = names; i != NULL; i = i->next) {
-	gdb_add_expression (inst, ss, i->data);
-	g_free (i->data);
-    }
-    g_list_free (names);
-
     /* Notify the symbol set that it has changed */
     gdf_libdryad_symbol_set_changed (ss);
 }
 
 void
-gdb_get_expression (GdbInstance *inst, GDF_Symbol *sym, const char *expr)
+gdb_get_expression (GdbInstance *inst, GNOME_Development_Symbol *sym, const char *expr)
 {
     sym->name = CORBA_string_dup (expr);
     sym->expression = CORBA_string_dup (expr);
@@ -107,22 +110,22 @@ gdb_get_expression (GdbInstance *inst, GDF_Symbol *sym, const char *expr)
 
 void
 gdb_expand_symbol (GdbInstance *inst, GdfLibdryadSymbolSet *ss, 
-		   GDF_Symbol *sym)
+		   GNOME_Development_Symbol *sym)
 {
     g_return_if_fail (sym->expandable);
 
     if (!sym->expanded) {
 	switch (sym->type) {
-	case GDF_TYPE_PTR :
+	case GNOME_Development_TYPE_PTR :
 	    expand_pointer (inst, ss, sym);
 	    break;
-	case GDF_TYPE_STRUCT :
+	case GNOME_Development_TYPE_STRUCT :
 	    expand_structure (inst, ss, sym);
 	    break;
-	case GDF_TYPE_ARRAY :
+	case GNOME_Development_TYPE_ARRAY :
 	    expand_array (inst, ss, sym);
 	    break;
-	case GDF_TYPE_ARRAY_SLICE :
+	case GNOME_Development_TYPE_ARRAY_SLICE :
 	    expand_array_slice (inst, ss, sym);
 	    break;
 	default:
@@ -134,12 +137,11 @@ gdb_expand_symbol (GdbInstance *inst, GdfLibdryadSymbolSet *ss,
 }
 
 GdbSymbolResult
-gdb_set_symbol_value (GdbInstance *inst, GDF_Symbol *sym, const char *value)
+gdb_set_symbol_value (GdbInstance *inst, GNOME_Development_Symbol *sym, const char *value)
 {
     char *cmd_str;
     char *line;
 
-    g_print ("here: %s, %s", sym->expression, value);
     cmd_str = g_strdup_printf ("set variable %s=%s", sym->expression, value);
     gdb_execute_command (inst, cmd_str);
     g_free (cmd_str);
@@ -160,7 +162,7 @@ gdb_set_symbol_value (GdbInstance *inst, GDF_Symbol *sym, const char *value)
 
 GdbSymbolResult
 gdb_cast (GdbInstance *inst, GdfLibdryadSymbolSet *ss, 
-	  GDF_Symbol *sym, const char *type)
+	  GNOME_Development_Symbol *sym, const char *type)
 {
     char *old;
     char *new;
@@ -189,7 +191,7 @@ gdb_cast (GdbInstance *inst, GdfLibdryadSymbolSet *ss,
 }
 
 static void
-update_symbol (GdbInstance *inst, GdfLibdryadSymbolSet *ss, GDF_Symbol *sym)
+update_symbol (GdbInstance *inst, GdfLibdryadSymbolSet *ss, GNOME_Development_Symbol *sym)
 {
 
     char *old_value;
@@ -206,28 +208,17 @@ update_symbol (GdbInstance *inst, GdfLibdryadSymbolSet *ss, GDF_Symbol *sym)
     read_value (inst, sym);
     
     if (strcmp (old_typename, sym->typename)) {
-	CORBA_any *event_any;
-	
 	destroy_children (sym);
 	
-	event_any = gdf_marshal_event_long ("symbol_type_changed", 
-					    sym->handle);
-	
-	gdf_event_channel_client_push (ss->event_channel,
-				       event_any);
-	CORBA_free (event_any);
+	send_event (ss->event_source, "symbol_type_changed", 
+		    gdf_marshal_event_long (sym->handle));
+
     }
     
     if (strcmp (old_value, sym->value) 
 	|| was_expandable != sym->expandable) {
-	CORBA_any *event_any;
-	
-	event_any = gdf_marshal_event_long ("symbol_changed", 
-					    sym->handle);
-	
-	gdf_event_channel_client_push (ss->event_channel,
-				       event_any);
-	CORBA_free (event_any);
+	send_event (ss->event_source, "symbol_changed", 
+		    gdf_marshal_event_long (sym->handle));
     }
     
     CORBA_free (old_value);
@@ -236,20 +227,20 @@ update_symbol (GdbInstance *inst, GdfLibdryadSymbolSet *ss, GDF_Symbol *sym)
 
 static void
 update_seq (GdbInstance *inst, GdfLibdryadSymbolSet *ss, 
-	    GDF_SymbolSequence *seq) 
+	    GNOME_Development_SymbolSequence *seq) 
 {
-    GDF_Symbol *sym;
+    GNOME_Development_Symbol *sym;
     int i;
 
     for (i = 0; i < seq->_length; i++) {
 	sym = &seq->_buffer[i];
 
-	if (sym->type != GDF_TYPE_ARRAY_SLICE) {
+	if (sym->type != GNOME_Development_TYPE_ARRAY_SLICE) {
 	    update_symbol (inst, ss, sym);
 	}
 	
 	update_seq (inst, ss, 
-		    (GDF_SymbolSequence*)sym->children._value);
+		    (GNOME_Development_SymbolSequence*)sym->children._value);
     }
 }
 
@@ -259,7 +250,7 @@ gdb_update_symbols (GdbInstance *inst, GdfLibdryadSymbolSet *ss)
     update_seq (inst, ss, ss->symbols);
 }
 
-GDF_SymbolSequence *
+GNOME_Development_SymbolSequence *
 gdb_allocate_symbols (void)
 {
     return init_seq ();
@@ -267,11 +258,11 @@ gdb_allocate_symbols (void)
 
 static void
 add_expression_to_seq  (GdbInstance *inst,
-			GDF_SymbolSequence *seq, 
+			GNOME_Development_SymbolSequence *seq, 
 			GdfLibdryadSymbolSet *ss, 
 			const char *expr)
 {
-    GDF_Symbol *sym;
+    GNOME_Development_Symbol *sym;
     
     grow_seq (seq, 1);
     sym = &seq->_buffer[seq->_length - 1];
@@ -289,7 +280,7 @@ gdb_add_expression (GdbInstance *inst,
 }
 
 void
-read_type (GdbInstance *inst, GDF_Symbol *sym)
+read_type (GdbInstance *inst, GNOME_Development_Symbol *sym)
 {
     char *line;
     char *p;
@@ -311,7 +302,7 @@ read_type (GdbInstance *inst, GDF_Symbol *sym)
 	    char *type;
 	    if (!strcmp (line, "\32\32error-begin"))
 		line = gdb_read_line (inst);
-	    if (!strncmp (line, "type = ", strlen ("type = ")))
+	    if (!strncmp (line, "type = ", 7))
 		line += 7;
 
 	    type = g_strdup (line);
@@ -359,24 +350,24 @@ read_type (GdbInstance *inst, GDF_Symbol *sym)
     g_assert (sym->typename);
     
     sym->expandable = FALSE;
-    sym->type = GDF_TYPE_NORMAL;
+    sym->type = GNOME_Development_TYPE_NORMAL;
     if (!strncmp (sym->typename, "struct", strlen ("struct"))
 	|| !strncmp (sym->typename, "class", strlen ("class"))) {
 	sym->expandable = TRUE;
-	sym->type = GDF_TYPE_STRUCT;
+	sym->type = GNOME_Development_TYPE_STRUCT;
     }
     if (sym->typename[strlen (sym->typename) - 1] == ']') {
 	sym->expandable = TRUE;
-	sym->type = GDF_TYPE_ARRAY;
+	sym->type = GNOME_Development_TYPE_ARRAY;
     }
     if (sym->typename[strlen (sym->typename) - 1] == '*') {
 	sym->expandable = TRUE;
-	sym->type = GDF_TYPE_PTR;
+	sym->type = GNOME_Development_TYPE_PTR;
     }
 }
 
 void
-read_value (GdbInstance *inst, GDF_Symbol *sym) 
+read_value (GdbInstance *inst, GNOME_Development_Symbol *sym) 
 {
     char *cmd_str;
     char *line;
@@ -384,10 +375,10 @@ read_value (GdbInstance *inst, GDF_Symbol *sym)
     g_assert (!sym->value);
     sym->value = NULL;
 
-    if (sym->type == GDF_TYPE_STRUCT) {
+    if (sym->type == GNOME_Development_TYPE_STRUCT) {
 	sym->value = CORBA_string_dup ("{...}");
 	return;
-    } else if (sym->type == GDF_TYPE_ARRAY) {
+    } else if (sym->type == GNOME_Development_TYPE_ARRAY) {
 	sym->value = CORBA_string_dup ("[...]");
 	return;
     }
@@ -447,10 +438,10 @@ read_value (GdbInstance *inst, GDF_Symbol *sym)
 
 static void
 add_child_expression (GdbInstance *inst, GdfLibdryadSymbolSet *ss, 
-		      GDF_Symbol *sym, const char *name, const char *expr)
+		      GNOME_Development_Symbol *sym, const char *name, const char *expr)
 {
-    GDF_Symbol *new_sym;
-    GDF_SymbolSequence *children;
+    GNOME_Development_Symbol *new_sym;
+    GNOME_Development_SymbolSequence *children;
 
     children = sym->children._value;
     add_expression_to_seq (inst, children, ss, expr);
@@ -461,7 +452,7 @@ add_child_expression (GdbInstance *inst, GdfLibdryadSymbolSet *ss,
 
 void
 expand_pointer (GdbInstance *inst, GdfLibdryadSymbolSet *ss, 
-		GDF_Symbol *sym)
+		GNOME_Development_Symbol *sym)
 {
     char *new_name;
     char *new_expr;
@@ -622,7 +613,7 @@ get_ptype_names (GdbInstance *inst, char *type_line,
 
 void
 expand_structure (GdbInstance *inst, GdfLibdryadSymbolSet *ss, 
-		  GDF_Symbol *sym)
+		  GNOME_Development_Symbol *sym)
 {
     char *expr;
     char *cmd_str;
@@ -656,7 +647,7 @@ expand_structure (GdbInstance *inst, GdfLibdryadSymbolSet *ss,
 
 void
 expand_array (GdbInstance *inst, GdfLibdryadSymbolSet *ss, 
-	      GDF_Symbol *sym)
+	      GNOME_Development_Symbol *sym)
 {
     char *typecpy;
     char *p;
@@ -681,7 +672,7 @@ expand_array (GdbInstance *inst, GdfLibdryadSymbolSet *ss,
 
 void
 expand_array_slice (GdbInstance *inst, GdfLibdryadSymbolSet *ss, 
-		    GDF_Symbol *sym)
+		    GNOME_Development_Symbol *sym)
 {
     char *namecpy;
     char *p, *p1;
@@ -707,12 +698,12 @@ expand_array_slice (GdbInstance *inst, GdfLibdryadSymbolSet *ss,
 }
 
 void
-add_slice (GdbInstance *inst, GdfLibdryadSymbolSet *ss, GDF_Symbol *sym,
+add_slice (GdbInstance *inst, GdfLibdryadSymbolSet *ss, GNOME_Development_Symbol *sym,
 	   unsigned begin, unsigned size)
 {
     char *name;
-    GDF_Symbol *new_sym;
-    GDF_SymbolSequence *seq;
+    GNOME_Development_Symbol *new_sym;
+    GNOME_Development_SymbolSequence *seq;
 
     seq = sym->children._value;
 
@@ -726,7 +717,7 @@ add_slice (GdbInstance *inst, GdfLibdryadSymbolSet *ss, GDF_Symbol *sym,
     new_sym->expression = CORBA_string_dup (sym->expression);
     new_sym->typename = CORBA_string_dup ("");
     new_sym->cast_to = CORBA_string_dup ("");
-    new_sym->type = GDF_TYPE_ARRAY_SLICE;
+    new_sym->type = GNOME_Development_TYPE_ARRAY_SLICE;
     new_sym->value = CORBA_string_dup("");
     new_sym->expandable = TRUE;
     new_sym->expanded = FALSE;
@@ -735,7 +726,7 @@ add_slice (GdbInstance *inst, GdfLibdryadSymbolSet *ss, GDF_Symbol *sym,
 }
 
 void
-expand_slice (GdbInstance *inst, GdfLibdryadSymbolSet *ss, GDF_Symbol *sym,
+expand_slice (GdbInstance *inst, GdfLibdryadSymbolSet *ss, GNOME_Development_Symbol *sym,
 	      unsigned start, unsigned num)
 {
     int i;
@@ -767,17 +758,17 @@ expand_slice (GdbInstance *inst, GdfLibdryadSymbolSet *ss, GDF_Symbol *sym,
 }
 
 static void
-destroy_children (GDF_Symbol *sym)
+destroy_children (GNOME_Development_Symbol *sym)
 {
     CORBA_free (sym->children._value);
     sym->children._value = init_seq ();
     sym->expanded = CORBA_FALSE;
 }
 
-static GDF_SymbolSequence *
+static GNOME_Development_SymbolSequence *
 init_seq (void)
 {
-    GDF_SymbolSequence *seq = GDF_SymbolSequence__alloc ();
+    GNOME_Development_SymbolSequence *seq = GNOME_Development_SymbolSequence__alloc ();
     seq->_length = 0;
     seq->_maximum = 0;
     seq->_buffer = NULL;
@@ -788,23 +779,23 @@ init_seq (void)
 }
 
 void
-grow_seq (GDF_SymbolSequence *seq, int amount)
+grow_seq (GNOME_Development_SymbolSequence *seq, int amount)
 {
     int i;
 
     int old_max = seq->_maximum;
-    GDF_Symbol *old_buf = seq->_buffer;
+    GNOME_Development_Symbol *old_buf = seq->_buffer;
 
     seq->_maximum += amount;
     seq->_length += amount;
-    seq->_buffer = CORBA_sequence_GDF_Symbol_allocbuf (seq->_maximum);
+    seq->_buffer = CORBA_sequence_GNOME_Development_Symbol_allocbuf (seq->_maximum);
 
     if (old_buf) {
 	ORBit_mem_info *block;
 
 	for (i = 0; i < old_max; i++) {
-	    GDF_Symbol *sym = &(seq->_buffer[i]);
-	    GDF_Symbol *old_sym = &old_buf[i];
+	    GNOME_Development_Symbol *sym = &(seq->_buffer[i]);
+	    GNOME_Development_Symbol *old_sym = &old_buf[i];
 	    sym->symbol_set = old_sym->symbol_set;
 	    sym->handle = old_sym->handle;
 	    sym->name = old_sym->name;
@@ -832,14 +823,14 @@ grow_seq (GDF_SymbolSequence *seq, int amount)
     }
 
     for (i = seq->_length - amount; i < seq->_length; i++) {
-	GDF_Symbol *sym = &(seq->_buffer[i]);
+	GNOME_Development_Symbol *sym = &(seq->_buffer[i]);
 	sym->symbol_set = -1;
 	sym->handle = -1;
-	sym->type = GDF_TYPE_NORMAL;
+	sym->type = GNOME_Development_TYPE_NORMAL;
 	sym->cast_to = CORBA_string_dup ("");
 	sym->expandable = CORBA_FALSE;
 	sym->expanded = CORBA_FALSE;
-	sym->children._type = TC_CORBA_sequence_GDF_Symbol;
+	sym->children._type = TC_CORBA_sequence_GNOME_Development_Symbol;
 	sym->children._value = init_seq ();
 	CORBA_any_set_release (&sym->children, CORBA_TRUE);
     }
