@@ -6,6 +6,7 @@
 typedef struct _GdfLibdryadDebugger GdfLibdryadDebugger;
 
 #include <bonobo/bonobo-object.h>
+#include <bonobo/bonobo-event-source.h>
 #include "../../lib/gdf.h"
 #include "libdryad.h"
 #include "gdf-libdryad-symbol-set.h"
@@ -15,15 +16,15 @@ BEGIN_GNOME_DECLS
 #define GDF_LIBDRYAD_DEBUGGER_TYPE (gdf_libdryad_debugger_get_type ())
 #define GDF_LIBDRYAD_DEBUGGER(o) (GTK_CHECK_CAST ((o), GDF_LIBDRYAD_DEBUGGER_TYPE, GdfLibdryadDebugger))
 #define GDF_LIBDRYAD_DEBUGGER_CLASS(k) (GTK_CHECK_CLASS_CAST ((k), GDF_LIBDRYAD_DEBUGGER_CLASS_TYPE, GdfLibdryadDebuggerClass))
-#define GDF_IS_LIBDRYAD_DEBUGGER(o) (GTK_CHECK_TYPE ((o), GDF_LIBDRYAD_DEBUGGER_TYPE))
-#define GDF_IS_LIBDRYAD_DEBUGGER_CLASS(k) (GTK_CHECK_CLASS_TYPE ((k), GDF_LIBDRYAD_DEBUGGER_TYPE))
+#define GNOME_Development_IS_LIBDRYAD_DEBUGGER(o) (GTK_CHECK_TYPE ((o), GDF_LIBDRYAD_DEBUGGER_TYPE))
+#define GNOME_Development_IS_LIBDRYAD_DEBUGGER_CLASS(k) (GTK_CHECK_CLASS_TYPE ((k), GDF_LIBDRYAD_DEBUGGER_TYPE))
 
 struct _GdfLibdryadDebugger {
     BonoboObject base;
 
     GdbInstance *gdb_inst;
-    GdfEventChannelClient *event_channel;
-    GDF_Debugger_StateFlag state;
+    BonoboEventSource *event_source;
+    GNOME_Development_Debugger_StateFlag state;
 
     gchar *tty_name;
     gint pending_exit;
@@ -37,8 +38,7 @@ struct _GdfLibdryadDebugger {
     int frame_changed;
 };
 
-typedef struct 
-{
+typedef struct {
     BonoboObjectClass parent_class;
 } GdfLibdryadDebuggerClass;
 
@@ -47,6 +47,13 @@ GtkType gdf_libdryad_debugger_get_type (void);
 
 void gdf_libdryad_debugger_update_symsets (GdfLibdryadDebugger *dbg, 
 					   gboolean include_locals);
+
+void send_event (BonoboEventSource *source, const char *name, 
+		 CORBA_any *data);
+
+void queue_event (BonoboEventSource *source, const char *name, 
+		  CORBA_any *data);
+
 END_GNOME_DECLS
 
 #endif
