@@ -20,11 +20,13 @@
  * Boston, MA 02111-1307, USA.  
  */
 
+#include <config.h>
+#include <gdl/gdl.h>
 #include "control-factories.h"
 #include "gdf-breakpoint-manager.h"
-#include "gdf-source-viewer-manager.h"
 #include "gdf-register-viewer.h"
 #include "gdf-locals-viewer.h"
+#include "gdf-output-terminal.h"
 #include "gdf-stack-browser.h"
 #include "../lib/gdf.h"
 
@@ -36,66 +38,47 @@ enum {
     PROP_SHOW_ENTRY
 };
 
-static void init_bpm_factory (void);
 static BonoboObject *bpm_factory (BonoboGenericFactory *fact,
-								 void *closure);
-static void init_source_viewer_factory (void);
-static BonoboObject *source_viewer_factory (BonoboGenericFactory *fact,
-                                           void *closure);
-static void init_stack_browser_factory (void);
+                                  void *closure);
 static BonoboObject *sb_factory (BonoboGenericFactory *fact,
                                  void *closure);
-static void init_register_viewer_factory (void);
 static BonoboObject *rv_factory (BonoboGenericFactory *fact,
                                 void *closure);
-static void init_locals_viewer_factory (void);
 static BonoboObject *lv_factory (BonoboGenericFactory *fact, void *closure);
-static void init_variable_viewer_factory (void);
 static BonoboObject *vv_factory (BonoboGenericFactory *fact, void *closure);
+static BonoboObject *ot_factory (BonoboGenericFactory *fact, void *closure);   
 
 static void set_prop (BonoboPropertyBag *bag,
                       const BonoboArg *arg,
                       guint arg_id,
+                      CORBA_Environment *ev,
                       gpointer user_data);
 static void get_prop (BonoboPropertyBag *bag,
                       BonoboArg *arg,
                       guint arg_id,
+                      CORBA_Environment *ev,
                       gpointer user_data);
 static GdfDebuggerClient *get_debugger (gchar *ior);
+GdfBreakpointSetClient *get_breakpoint_set (gchar *ior);
 
-static void
-control_server_quit ()
+static BonoboObject *
+control_factory (BonoboGenericFactory *factory, 
+                 const char *component_id,
+                 gpointer closure)
 {
-	gtk_main_quit ();
-}
-
-void
-init_control_factories (void)
-{	
-	gdf_server_manager_init (control_server_quit);
-	init_bpm_factory ();
-	init_source_viewer_factory ();
-    init_stack_browser_factory ();
-    init_register_viewer_factory ();
-    init_locals_viewer_factory ();
-    init_variable_viewer_factory ();
-}
-
-static void 
-init_bpm_factory (void)
-{
-	static BonoboGenericFactory *bpm_control_factory = NULL;
-
-	if (bpm_control_factory != NULL)
-		return;
-
-	bpm_control_factory = 
-		bonobo_generic_factory_new ("OAFIID:control-factory:gdf-breakpoint-manager:8aaa6895-a3dc-4afd-b6fe-03abcfed2fc9",
-                                    bpm_factory, NULL);
-	
-	if (bpm_control_factory == NULL) 
-		g_error (_("Could not initialize Breakpoint Manager factory."));
-	
+    if (!strcmp (component_id, "OAFIID:GNOME_Development_BreakpointManager"))
+        return bpm_factory (factory, closure);
+    if (!strcmp (component_id, "OAFIID:GNOME_Development_StackBrowser"))
+        return sb_factory (factory, closure);
+    if (!strcmp (component_id, "OAFIID:GNOME_Development_RegisterViewer"))
+        return rv_factory (factory, closure);
+    if (!strcmp (component_id, "OAFIID:GNOME_Development_LocalsViewer"))
+        return lv_factory (factory, closure);
+    if (!strcmp (component_id, "OAFIID:GNOME_Development_VariableViewer"))
+        return vv_factory (factory, closure);
+    if (!strcmp (component_id, "OAFIID:GNOME_Development_OutputTerminal"))
+        return ot_factory (factory, closure);
+    return NULL;
 }
 
 static BonoboObject *
@@ -109,13 +92,12 @@ bpm_factory (BonoboGenericFactory *fact,
 	/* Create the control */
 	bpm = gdf_breakpoint_manager_new ();
 	gtk_widget_show (GTK_WIDGET (bpm));
-	gdf_server_manager_register_object (GTK_OBJECT (bpm));
 	
 	control = bonobo_control_new (GTK_WIDGET (bpm));
 	
 	/* Create the properties */
 	pb = bonobo_property_bag_new (get_prop, set_prop, bpm);
-	bonobo_control_set_property_bag (control, pb);
+	bonobo_control_set_properties (control, pb);
 	bonobo_property_bag_add (pb, "debugger-ior", PROP_DEBUGGER_IOR,
                              BONOBO_ARG_STRING, NULL, 
                              "Object reference of the debugging backend", 0);
@@ -123,66 +105,6 @@ bpm_factory (BonoboGenericFactory *fact,
 	return BONOBO_OBJECT (control);
 }
 
-static void 
-init_source_viewer_factory (void)
-{
-	static BonoboGenericFactory *sv_control_factory = NULL;
-
-	if (sv_control_factory != NULL)
-		return;
-
-	sv_control_factory = 
-		bonobo_generic_factory_new ("OAFIID:control-factory:gdf-default-source-viewer:a8d7b557-e629-4365-9faf-9c30556bdeff",
-								   source_viewer_factory, NULL);
-	
-	if (sv_control_factory == NULL) 
-		g_error (_("Could not initialize Source Viewer factory."));
-	
-}
-
-static BonoboObject *
-source_viewer_factory (BonoboGenericFactory *fact,
-					   void *closure)
-{
-	BonoboPropertyBag *pb;
-	BonoboControl *control;
-	GdfSourceViewerManager *svm;
-
-	/* Create the control */
-	svm = gdf_source_viewer_manager_new ();
-	gtk_widget_show (GTK_WIDGET (svm));
-	gdf_server_manager_register_object (GTK_OBJECT (svm));
-	
-	control = bonobo_control_new (GTK_WIDGET (svm));
-
-	/* Create the properties */
-    pb = bonobo_property_bag_new (get_prop, set_prop, svm);
-	bonobo_control_set_property_bag (control, pb);
-	bonobo_property_bag_add (pb, "debugger-ior", PROP_DEBUGGER_IOR,
-                             BONOBO_ARG_STRING, NULL, 
-                             "Object reference of the debugging backend", 0);
-
-	
-	return BONOBO_OBJECT (control);
-}
-
-static void 
-init_stack_browser_factory (void)
-{
-	static BonoboGenericFactory *sb_control_factory = NULL;
-
-	if (sb_control_factory != NULL)
-		return;
-
-    sb_control_factory = 
-		bonobo_generic_factory_new ("OAFIID:control-factory:gdf-stack-browser:726853bd-d335-4b01-a2d4-b7fb52562525",
-                                    sb_factory, NULL);
-	
-	if (sb_control_factory == NULL) 
-		g_error (_("Could not initialize Stack Browser factory."));
-	
-}
-
 static BonoboObject *
 sb_factory (BonoboGenericFactory *fact,
             void *closure)
@@ -194,13 +116,12 @@ sb_factory (BonoboGenericFactory *fact,
 	/* Create the control */
 	sb = gdf_stack_browser_new ();
 	gtk_widget_show (GTK_WIDGET (sb));
-	gdf_server_manager_register_object (GTK_OBJECT (sb));
 	
 	control = bonobo_control_new (GTK_WIDGET (sb));
 	
 	/* Create the properties */
 	pb = bonobo_property_bag_new (get_prop, set_prop, sb);
-	bonobo_control_set_property_bag (control, pb);
+	bonobo_control_set_properties (control, pb);
 	bonobo_property_bag_add (pb, "debugger-ior", PROP_DEBUGGER_IOR,
                              BONOBO_ARG_STRING, NULL, 
                              "Object reference of the debugging backend", 0);
@@ -208,23 +129,6 @@ sb_factory (BonoboGenericFactory *fact,
 	return BONOBO_OBJECT (control);
 }
 
-static void 
-init_register_viewer_factory (void)
-{
-	static BonoboGenericFactory *rv_control_factory = NULL;
-
-	if (rv_control_factory != NULL)
-		return;
-
-    rv_control_factory = 
-		bonobo_generic_factory_new ("OAFIID:control-factory:gdf-register-viewer:12a0a3e5-8972-4ea1-9308-01789bc2962d",
-                                    rv_factory, NULL);
-	
-	if (rv_control_factory == NULL) 
-		g_error (_("Could not initialize Register Viewer factory."));
-	
-}
-
 static BonoboObject *
 rv_factory (BonoboGenericFactory *fact,
             void *closure)
@@ -232,17 +136,16 @@ rv_factory (BonoboGenericFactory *fact,
 	BonoboPropertyBag *pb;
 	BonoboControl *control;
 	GtkWidget *rv;
-
+    
 	/* Create the control */
 	rv = gdf_register_viewer_new ();
 	gtk_widget_show (GTK_WIDGET (rv));
-	gdf_server_manager_register_object (GTK_OBJECT (rv));
 	
 	control = bonobo_control_new (GTK_WIDGET (rv));
 	
 	/* Create the properties */
 	pb = bonobo_property_bag_new (get_prop, set_prop, rv);
-	bonobo_control_set_property_bag (control, pb);
+	bonobo_control_set_properties (control, pb);
 	bonobo_property_bag_add (pb, "debugger-ior", PROP_DEBUGGER_IOR,
                              BONOBO_ARG_STRING, NULL, 
                              "Object reference of the debugging backend", 0);
@@ -250,23 +153,6 @@ rv_factory (BonoboGenericFactory *fact,
 	return BONOBO_OBJECT (control);
 }
 
-static void 
-init_locals_viewer_factory (void)
-{
-	static BonoboGenericFactory *lv_control_factory = NULL;
-
-	if (lv_control_factory != NULL)
-		return;
-
-    lv_control_factory = 
-		bonobo_generic_factory_new ("OAFIID:control-factory:gdf-locals-viewer:412ac1ce-4cf1-4b24-96c1-4efae3d5a1a3",
-                                    lv_factory, NULL);
-	
-	if (lv_control_factory == NULL) 
-		g_error (_("Could not initialize locals viewer factory."));
-	
-}
-
 static BonoboObject *
 lv_factory (BonoboGenericFactory *fact,
             void *closure)
@@ -278,13 +164,12 @@ lv_factory (BonoboGenericFactory *fact,
 	/* Create the control */
 	lv = GTK_WIDGET (gdf_locals_viewer_new ());
 	gtk_widget_show (GTK_WIDGET (lv));
-	gdf_server_manager_register_object (GTK_OBJECT (lv));
 	
 	control = bonobo_control_new (GTK_WIDGET (lv));
 	
 	/* Create the properties */
 	pb = bonobo_property_bag_new (get_prop, set_prop, lv);
-	bonobo_control_set_property_bag (control, pb);
+	bonobo_control_set_properties (control, pb);
 	bonobo_property_bag_add (pb, "debugger-ior", PROP_DEBUGGER_IOR,
                              BONOBO_ARG_STRING, NULL, 
                              "Object reference of the debugging backend", 0);
@@ -292,23 +177,6 @@ lv_factory (BonoboGenericFactory *fact,
 	return BONOBO_OBJECT (control);
 }
 
-static void 
-init_variable_viewer_factory (void)
-{
-	static BonoboGenericFactory *vv_control_factory = NULL;
-
-	if (vv_control_factory != NULL)
-		return;
-
-    vv_control_factory = 
-		bonobo_generic_factory_new ("OAFIID:control-factory:gdf-variable-viewer:cf41eceb-b5f5-447a-a0e6-77c48103a1ae",
-                                    vv_factory, NULL);
-	
-	if (vv_control_factory == NULL) 
-		g_error (_("Could not initialize variable viewer factory."));
-	
-}
-
 static BonoboObject *
 vv_factory (BonoboGenericFactory *fact,
             void *closure)
@@ -321,13 +189,12 @@ vv_factory (BonoboGenericFactory *fact,
 	/* Create the control */
 	vv = GTK_WIDGET (gdf_variable_viewer_new ());
 	gtk_widget_show (GTK_WIDGET (vv));
-	gdf_server_manager_register_object (GTK_OBJECT (vv));
 	
 	control = bonobo_control_new (GTK_WIDGET (vv));
 	
 	/* Create the properties */
 	pb = bonobo_property_bag_new (get_prop, set_prop, vv);
-	bonobo_control_set_property_bag (control, pb);
+	bonobo_control_set_properties (control, pb);
 	bonobo_property_bag_add (pb, "debugger-ior", PROP_DEBUGGER_IOR,
                              BONOBO_ARG_STRING, NULL, 
                              "Object reference of the debugging backend", 
@@ -351,18 +218,16 @@ static void
 set_prop (BonoboPropertyBag *bag,
           const BonoboArg *arg,
           guint arg_id,
+          CORBA_Environment *ev,
           gpointer user_data)
 {
     GtkObject *obj = user_data;
-    
-    GDF_TRACE ();
 
     switch (arg_id) {
     case PROP_DEBUGGER_IOR :
     {
         GdfDebuggerClient *dbg;
         char *s;
-
         s = BONOBO_ARG_GET_STRING (arg);
         
         if (strcmp (s, ""))
@@ -372,6 +237,8 @@ set_prop (BonoboPropertyBag *bag,
         
         gtk_object_set (GTK_OBJECT (obj), "debugger", 
                         (GtkObject *)dbg, NULL);
+        if (dbg)
+            gtk_object_unref (GTK_OBJECT (dbg));
         break;
     }
     case PROP_SHOW_ENTRY :
@@ -384,10 +251,37 @@ set_prop (BonoboPropertyBag *bag,
     }
 }
 
+static BonoboObject *
+ot_factory (BonoboGenericFactory *fact,
+            void *closure)
+{
+    BonoboPropertyBag *pb;
+    BonoboControl *control;
+    GtkWidget *ot;
+
+    /* Create the control */
+    ot = GTK_WIDGET (gdf_output_terminal_new ());
+    gtk_widget_show (GTK_WIDGET (ot));
+    
+    control = bonobo_control_new (GTK_WIDGET (ot));
+    
+    /* Create the properties */
+    pb = bonobo_property_bag_new (get_prop, set_prop, ot);
+    bonobo_control_set_properties (control, pb);
+    bonobo_property_bag_add (pb, "debugger-ior", PROP_DEBUGGER_IOR,
+                             BONOBO_ARG_STRING, NULL,
+                             "Object reference of the debugging backend",
+                             BONOBO_PROPERTY_READABLE
+                             | BONOBO_PROPERTY_WRITEABLE);
+
+    return BONOBO_OBJECT (control);
+}
+
 static void
 get_prop (BonoboPropertyBag *bag,
           BonoboArg *arg,
           guint arg_id,
+          CORBA_Environment *ev,
           gpointer user_data)
 {
     GtkObject *obj = user_data;
@@ -432,6 +326,8 @@ get_prop (BonoboPropertyBag *bag,
     }
 }
 
+
+
 static GdfDebuggerClient *
 get_debugger (gchar *ior)
 {
@@ -457,7 +353,46 @@ get_debugger (gchar *ior)
 	
 		dbg = gdf_debugger_client_new_from_corba (objref);
 		g_hash_table_insert (active_debuggers, (gpointer)ior, (gpointer)dbg);
-	}
+	} else {
+        gtk_object_ref (GTK_OBJECT (dbg));
+    }
 	
 	return dbg;
 }
+
+GdfBreakpointSetClient *
+get_breakpoint_set (gchar *ior)
+{
+	CORBA_Object objref;
+	GdfBreakpointSetClient *bs;
+    CORBA_Environment ev;
+
+    static GHashTable *active = NULL;
+	
+    if (ior[0] == '\0')
+        return NULL;
+
+	if (!active) 
+		active = g_hash_table_new (g_str_hash, g_str_equal);
+
+	bs = (GdfBreakpointSetClient *)g_hash_table_lookup (active, ior);
+	
+	if (!bs) {
+		CORBA_exception_init (&ev);
+		objref = CORBA_ORB_string_to_object (oaf_orb_get (), ior, &ev);
+		/* FIXME: Check for exceptions */
+		CORBA_exception_free (&ev);
+	
+		bs = gdf_breakpoint_set_client_new_from_corba (objref);
+		g_hash_table_insert (active, (gpointer)ior, (gpointer)bs);
+	} else {
+        gtk_object_ref (GTK_OBJECT (bs));
+    }
+	
+	return bs;
+}
+    
+BONOBO_OAF_FACTORY_MULTI ("OAFIID:GNOME_Development_DebuggerControlFactory",
+                          "Factory for the gnome-debug controls.",
+                          VERSION, 
+                          control_factory, NULL);
