@@ -20,8 +20,8 @@
  * Boston, MA 02111-1307, USA.  
  */
 
-#ifndef __GDF_LOCALS_VIEWER_H__
-#define __GDF_LOCALS_VIEWER_H__
+#ifndef __GNOME_Development_LOCALS_VIEWER_H__
+#define __GNOME_Development_LOCALS_VIEWER_H__
 
 #include <gnome.h>
 #include "gdf-variable-viewer.h"
@@ -33,11 +33,11 @@ typedef struct _GdfLocalsViewer      GdfLocalsViewer;
 typedef struct _GdfLocalsViewerClass GdfLocalsViewerClass;
 typedef struct _GdfLocalsViewerPriv  GdfLocalsViewerPriv;
 
-#define GDF_LOCALS_VIEWER_TYPE        (gdf_locals_viewer_get_type ())
-#define GDF_LOCALS_VIEWER(o)          (GTK_CHECK_CAST ((o), GDF_LOCALS_VIEWER_TYPE, GdfLocalsViewer))
-#define GDF_LOCALS_VIEWER_CLASS(k)    (GTK_CHECK_CLASS_CAST((k), GDF_LOCALS_VIEWER_TYPE, GdfLocalsViewerClass))
-#define GDF_IS_LOCALS_VIEWER(o)       (GTK_CHECK_TYPE ((o), GDF_LOCALS_VIEWER_TYPE))
-#define GDF_IS_LOCALS_VIEWER_CLASS(k) (GTK_CHECK_CLASS_TYPE ((k), GDF_LOCALS_VIEWER_TYPE))
+#define GNOME_Development_LOCALS_VIEWER_TYPE        (gdf_locals_viewer_get_type ())
+#define GNOME_Development_LOCALS_VIEWER(o)          (GTK_CHECK_CAST ((o), GNOME_Development_LOCALS_VIEWER_TYPE, GdfLocalsViewer))
+#define GNOME_Development_LOCALS_VIEWER_CLASS(k)    (GTK_CHECK_CLASS_CAST((k), GNOME_Development_LOCALS_VIEWER_TYPE, GdfLocalsViewerClass))
+#define GNOME_Development_IS_LOCALS_VIEWER(o)       (GTK_CHECK_TYPE ((o), GNOME_Development_LOCALS_VIEWER_TYPE))
+#define GNOME_Development_IS_LOCALS_VIEWER_CLASS(k) (GTK_CHECK_CLASS_TYPE ((k), GNOME_Development_LOCALS_VIEWER_TYPE))
 
 struct _GdfLocalsViewer {
 	GdfVariableViewer parent;
