@@ -23,13 +23,26 @@
 #include <gnome.h>
 #include "gdf-register-viewer.h"
 
+#include <gal/widgets/e-canvas.h>
+#include <gal/widgets/e-popup-menu.h>
+#include <gal/e-table/e-table-header-item.h>
+#include <gal/e-table/e-table-item.h>
+#include <gal/util/e-util.h>
+#include <gal/e-table/e-table.h>
+#include <gal/e-table/e-table-header-item.h>
+#include <gal/e-table/e-table-item.h>
+#include <gal/e-table/e-table-scrolled.h>
+#include <gal/e-table/e-table-simple.h>
+#include <gal/e-table/e-cell-text.h>
+#include <gal/e-table/e-cell-checkbox.h>
+
 struct _GdfRegisterViewerPriv {
-    GtkWidget *vbox;
     GtkWidget *show_fp;
-    GtkWidget *clist;
-    GtkWidget *scrolled;
+    
+    ETableModel *e_table_model;
 
     GdfDebuggerClient *dbg;
+    GNOME_Development_RegisterList *regs;
 
     int corefile_loaded_sig;
     int corefile_unloaded_sig;
@@ -44,6 +57,12 @@ enum {
     ARG_DEBUGGER
 };
 
+enum {
+    COL_NAME,
+    COL_VALUE,
+    LAST_COL
+};
+
 static void register_viewer_init (GdfRegisterViewer *rv);
 static void register_viewer_class_init (GdfRegisterViewerClass *klass);
 static void register_viewer_destroy (GtkObject *object);
@@ -61,9 +80,22 @@ static void execution_stopped_cb (GdfDebuggerClient *dbg,
 static void show_fp_toggled_cb (GtkWidget *toggle_bugger, 
                                 GdfRegisterViewer *rv);
 static void create_children (GdfRegisterViewer *rv);
+static void clear_register_viewer (GdfRegisterViewer *rv);
 
 static GtkFrameClass *parent_class;
 
+const char *register_viewer_spec =
+"<ETableSpecification click-to-add=\"false\" draw-grid=\"true\">"
+"  <ETableColumn model_col=\"0\" _title=\"Reg\" expansion=\"0.25\" minimum_width=\"30\" resizable=\"true\" cell=\"string\" compare=\"string\"/>"
+"  <ETableColumn model_col=\"1\" _title=\"Value\" expansion=\"1.0\" minimum_width=\"30\" resizable=\"true\" cell=\"string\" compare=\"string\"/>"
+"  <ETableState>"
+"    <column source=\"0\"/>"
+"    <column source=\"1\"/>"
+"    <grouping></grouping>"
+"  </ETableState>"
+"</ETableSpecification>";
+
+
 /*
  * Public Interface 
  */
@@ -106,7 +138,7 @@ gdf_register_viewer_set_debugger (GdfRegisterViewer *rv,
                                    GdfDebuggerClient *dbg)
 {
     g_return_if_fail (rv != NULL);
-    g_return_if_fail (GDF_IS_REGISTER_VIEWER (rv));
+    g_return_if_fail (GNOME_Development_IS_REGISTER_VIEWER (rv));
 	
     if (rv->priv->dbg) {
         disconnect_debugger_signals (rv);
@@ -152,6 +184,7 @@ register_viewer_init (GdfRegisterViewer *rv)
     rv->priv = g_new0 (GdfRegisterViewerPriv, 1);
     
     rv->priv->dbg = NULL;
+    rv->priv->regs = NULL;
 	
     create_children (rv);
 }
@@ -159,11 +192,16 @@ register_viewer_init (GdfRegisterViewer *rv)
 void
 register_viewer_destroy (GtkObject *obj)
 {
-    GdfRegisterViewer *rv = GDF_REGISTER_VIEWER (obj);
-    
+    GdfRegisterViewer *rv = GNOME_Development_REGISTER_VIEWER (obj);
+     
     if (rv->priv->dbg)
         gtk_object_unref (GTK_OBJECT (rv->priv->dbg));
     
+    if (rv->priv->regs) {
+        CORBA_free (rv->priv->regs);
+        rv->priv->regs = NULL;
+    }
+
     g_free (rv->priv);
     
     if (GTK_OBJECT_CLASS (parent_class)->destroy)
@@ -175,7 +213,7 @@ get_arg (GtkObject *object,
          GtkArg *arg, 
          guint arg_id)
 {
-    GdfRegisterViewer *rv = GDF_REGISTER_VIEWER (object);
+    GdfRegisterViewer *rv = GNOME_Development_REGISTER_VIEWER (object);
     
     switch (arg_id) {
     case ARG_DEBUGGER :
@@ -191,7 +229,7 @@ set_arg (GtkObject *object,
          GtkArg *arg, 
          guint arg_id)
 {
-    GdfRegisterViewer *rv = GDF_REGISTER_VIEWER (object);
+    GdfRegisterViewer *rv = GNOME_Development_REGISTER_VIEWER (object);
     
     switch (arg_id) {
     case ARG_DEBUGGER :
@@ -203,7 +241,6 @@ set_arg (GtkObject *object,
     }   
 }
 
-
 /* 
  * Helper functions 
  */
@@ -219,8 +256,8 @@ connect_debugger_signals (GdfRegisterViewer *rv)
     rv->priv->corefile_unloaded_sig = 
         gtk_signal_connect_object (GTK_OBJECT (rv->priv->dbg),
                                    "corefile_unloaded",
-                                   GTK_SIGNAL_FUNC (gtk_clist_clear),
-                                   (gpointer)rv->priv->clist);
+                                   GTK_SIGNAL_FUNC (clear_register_viewer),
+                                   (gpointer)rv);
     rv->priv->execution_stopped_sig = 
         gtk_signal_connect (GTK_OBJECT (rv->priv->dbg), 
                             "execution_stopped",
@@ -229,18 +266,18 @@ connect_debugger_signals (GdfRegisterViewer *rv)
     rv->priv->execution_exited_sig = 
         gtk_signal_connect_object (GTK_OBJECT (rv->priv->dbg),
                                    "execution_exited",
-                                   GTK_SIGNAL_FUNC (gtk_clist_clear),
-                                   (gpointer)rv->priv->clist);
+                                   GTK_SIGNAL_FUNC (clear_register_viewer),
+                                   (gpointer)rv);
     rv->priv->execution_killed_sig = 
         gtk_signal_connect_object (GTK_OBJECT (rv->priv->dbg),
                                    "execution_killed",
-                                   GTK_SIGNAL_FUNC (gtk_clist_clear),
-                                   (gpointer)rv->priv->clist);
+                                   GTK_SIGNAL_FUNC (clear_register_viewer),
+                                   (gpointer)rv);
     rv->priv->program_unloaded_sig = 
         gtk_signal_connect_object (GTK_OBJECT (rv->priv->dbg),
                                    "program_unloaded",
-                                   GTK_SIGNAL_FUNC (gtk_clist_clear),
-                                   (gpointer)rv->priv->clist);
+                                   GTK_SIGNAL_FUNC (clear_register_viewer),
+                                   (gpointer)rv);
 }
 
 void
@@ -261,28 +298,18 @@ disconnect_debugger_signals (GdfRegisterViewer *rv)
 void
 load_registers (GdfRegisterViewer *rv)
 {
-    GDF_RegisterList *regs;
     GdfDebuggerClientResult res;
-    int i;
-    gchar *text[2];
-    
+    e_table_model_pre_change (rv->priv->e_table_model);
+
+    if (rv->priv->regs) {
+        CORBA_free (rv->priv->regs);
+    }
+
     res = gdf_debugger_client_get_registers (rv->priv->dbg,
                                              (gboolean)GTK_TOGGLE_BUTTON (rv->priv->show_fp)->active,
-                                             &regs);
-    if (res != GDF_DEBUGGER_CLIENT_OK)
-        return;
-    
-    gtk_clist_freeze (GTK_CLIST (rv->priv->clist));
-    gtk_clist_clear (GTK_CLIST (rv->priv->clist));
+                                             &rv->priv->regs);
 
-    for (i = 0; i < regs->_length; i++) {
-        text[0] = regs->_buffer[i].name;
-        text[1] = regs->_buffer[i].value;
-        gtk_clist_append (GTK_CLIST (rv->priv->clist), text);
-        
-    }
-    gtk_clist_thaw (GTK_CLIST (rv->priv->clist));
-    CORBA_free (regs);
+    e_table_model_changed (rv->priv->e_table_model);
 }
 
 void
@@ -295,39 +322,128 @@ execution_stopped_cb (GdfDebuggerClient *dbg,
 void
 show_fp_toggled_cb (GtkWidget *toggle_bugger, GdfRegisterViewer *rv)
 {
-    load_registers (rv);
+    if (rv->priv->dbg) {
+        load_registers (rv);
+    }
+}
+
+static int
+col_count (ETableModel *etm, void *data)
+{
+    return LAST_COL;
+}
+
+static int
+row_count (ETableModel *etm, void *data)
+{
+    GdfRegisterViewer *rv = data;
+    if (rv->priv->regs) {
+        return rv->priv->regs->_length;
+    } else {
+        return 0;
+    }
+}
+
+static void *
+value_at (ETableModel *etm, int col, int row, void *data)
+{
+    GdfRegisterViewer *rv = data;
+    if (rv->priv->regs) {                         
+        if (col == COL_NAME) {
+            return rv->priv->regs->_buffer[row].name;
+        } else {
+            return rv->priv->regs->_buffer[row].value;
+        }
+    } else {
+        return 0;
+    }
+}
+
+static void
+set_value_at (ETableModel *etm, int col, int row, const void *val, void *data)
+{
+    GdfRegisterViewer *rv = data;
+    GdfDebuggerClientResult res;
+    char *new_val;
+    
+    g_return_if_fail (col == COL_VALUE);
+
+    res = gdf_debugger_client_set_register_value (rv->priv->dbg,
+                                                  rv->priv->regs->_buffer[row].name,
+                                                  val);
+    if (res == GDF_DEBUGGER_CLIENT_OK) {
+        CORBA_free (rv->priv->regs->_buffer[row].value);
+        res = gdf_debugger_client_get_register_value (rv->priv->dbg,
+                                                      rv->priv->regs->_buffer[row].name,
+                                                      &new_val);
+        if (res == GDF_DEBUGGER_CLIENT_OK) {
+            e_table_model_pre_change (etm);
+            rv->priv->regs->_buffer[row].value = CORBA_string_dup (new_val);
+            g_free (new_val);
+            e_table_model_row_changed (etm, row);
+        }
+    } 
+}
+
+static gboolean 
+is_cell_editable (ETableModel *etm, int col, int row, void *data)
+{
+    return (col == COL_VALUE);
+}
+
+static gboolean 
+value_is_empty (ETableModel *etm, int col, const void *value, void *data)
+{
+    return !(value && *(char*)value);
+}
+
+static char *
+value_to_string (ETableModel *etm, int col, const void *val, void *data)
+{
+    return g_strdup (val);
 }
 
 void
 create_children (GdfRegisterViewer *rv)
 {
-    gchar *titles[] = { N_("Reg"), N_("Value") };
-    
+    GtkWidget *e_table;
+    GtkWidget *vbox;
+
     rv->priv->show_fp = 
         gtk_check_button_new_with_label (_("Include floating point"));
 
     gtk_signal_connect (GTK_OBJECT (rv->priv->show_fp), "toggled",
                         GTK_SIGNAL_FUNC (show_fp_toggled_cb), rv);
 
-    rv->priv->clist = gtk_clist_new_with_titles (2, titles);
+    rv->priv->e_table_model = 
+        e_table_simple_new (col_count, row_count, value_at,
+                            set_value_at, is_cell_editable,
+                            NULL, NULL, NULL,
+                            value_is_empty,
+                            value_to_string, rv);
     
-    gtk_clist_set_column_width (GTK_CLIST (rv->priv->clist), 0, 40);
-	
-    rv->priv->scrolled = gtk_scrolled_window_new (NULL, NULL);
-    gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (rv->priv->scrolled),
-                                    GTK_POLICY_AUTOMATIC,
-                                    GTK_POLICY_AUTOMATIC);
-	
-    rv->priv->vbox = gtk_vbox_new (FALSE, 0);
-    gtk_box_pack_start (GTK_BOX (rv->priv->vbox), rv->priv->show_fp, 
+    e_table = 
+        e_table_scrolled_new (rv->priv->e_table_model,
+                              NULL, register_viewer_spec,
+                              NULL);
+
+    vbox = gtk_vbox_new (FALSE, 0);
+    gtk_box_pack_start (GTK_BOX (vbox), rv->priv->show_fp, 
                         FALSE, FALSE, 0);
-    gtk_box_pack_start (GTK_BOX (rv->priv->vbox), rv->priv->scrolled,
+    gtk_box_pack_start (GTK_BOX (vbox), e_table,
                         TRUE, TRUE, 0);
-    gtk_container_add (GTK_CONTAINER (rv->priv->scrolled), rv->priv->clist);
-    gtk_container_add (GTK_CONTAINER (rv), rv->priv->vbox);
+    gtk_container_add (GTK_CONTAINER (rv), vbox);
     gtk_widget_show (rv->priv->show_fp);
-    gtk_widget_show (rv->priv->clist);
-    gtk_widget_show (rv->priv->scrolled);
-    gtk_widget_show (rv->priv->vbox);
+    gtk_widget_show (e_table);
+    gtk_widget_show (vbox);
+}
+
+void
+clear_register_viewer (GdfRegisterViewer *rv)
+{
+    e_table_model_pre_change (rv->priv->e_table_model);
+    CORBA_free (rv->priv->regs);
+    rv->priv->regs = NULL;
+    e_table_model_changed (rv->priv->e_table_model);
 }
 
