@@ -68,7 +68,7 @@ static void set_arg (GtkObject *object,
                      guint arg_id);
 static void create_children (GdfVariableViewer *vv);
 static void add_node (GdfVariableViewer *vv, GtkCTreeNode *parent, 
-                      GDF_Symbol *sym);
+                      GNOME_Development_Symbol *sym);
 static void add_dummy_child (GdfVariableViewer *vv, GtkCTreeNode *parent);
 static void clear_variable_viewer (GdfVariableViewer *vv);
 static void connect_debugger_signals (GdfVariableViewer *vv);
@@ -173,7 +173,7 @@ gdf_variable_viewer_view_symbol_set (GdfVariableViewer *vv,
                                      GdfSymbolSetClient *ss)
 {
     g_return_if_fail (vv != NULL);
-	g_return_if_fail (GDF_IS_VARIABLE_VIEWER (vv));
+	g_return_if_fail (GNOME_Development_IS_VARIABLE_VIEWER (vv));
 
     vv->priv->view_locals = FALSE;
 
@@ -193,7 +193,7 @@ void
 gdf_variable_viewer_view_locals (GdfVariableViewer *vv)
 {
     g_return_if_fail (vv != NULL);
-	g_return_if_fail (GDF_IS_VARIABLE_VIEWER (vv));
+	g_return_if_fail (GNOME_Development_IS_VARIABLE_VIEWER (vv));
 
     vv->priv->view_locals = TRUE;
 
@@ -206,11 +206,11 @@ gdf_variable_viewer_view_locals (GdfVariableViewer *vv)
 
 void 
 gdf_variable_viewer_view_symbol (GdfVariableViewer *vv,
-                                 GDF_Symbol *sym)
+                                 GNOME_Development_Symbol *sym)
 {
 	g_return_if_fail (vv != NULL);
 	g_return_if_fail (sym != NULL);
-	g_return_if_fail (GDF_IS_VARIABLE_VIEWER (vv));
+	g_return_if_fail (GNOME_Development_IS_VARIABLE_VIEWER (vv));
 
     add_node (vv, NULL, sym);
 }
@@ -219,7 +219,7 @@ void
 gdf_variable_viewer_clear (GdfVariableViewer *vv)
 {
 	g_return_if_fail (vv != NULL);
-	g_return_if_fail (GDF_IS_VARIABLE_VIEWER (vv));
+	g_return_if_fail (GNOME_Development_IS_VARIABLE_VIEWER (vv));
 
     clear_variable_viewer (vv);
 }
@@ -229,7 +229,7 @@ gdf_variable_viewer_set_debugger (GdfVariableViewer *vv,
                                   GdfDebuggerClient *dbg)
 {
 	g_return_if_fail (vv != NULL);
-	g_return_if_fail (GDF_IS_VARIABLE_VIEWER (vv));
+	g_return_if_fail (GNOME_Development_IS_VARIABLE_VIEWER (vv));
 
     gdf_variable_viewer_clear (vv);
 
@@ -324,7 +324,7 @@ variable_viewer_init (GdfVariableViewer *vv)
 void 
 variable_viewer_destroy (GtkObject *obj)
 {
-	GdfVariableViewer *vv = GDF_VARIABLE_VIEWER (obj);
+	GdfVariableViewer *vv = GNOME_Development_VARIABLE_VIEWER (obj);
 	
 	g_return_if_fail (obj != NULL);
 	
@@ -347,7 +347,7 @@ get_arg (GtkObject *object,
          GtkArg *arg, 
          guint arg_id)
 {
-    GdfVariableViewer *vv = GDF_VARIABLE_VIEWER (object);
+    GdfVariableViewer *vv = GNOME_Development_VARIABLE_VIEWER (object);
     
     switch (arg_id) {
     case ARG_DEBUGGER :
@@ -366,7 +366,7 @@ set_arg (GtkObject *object,
          GtkArg *arg, 
          guint arg_id)
 {
-    GdfVariableViewer *vv = GDF_VARIABLE_VIEWER (object);
+    GdfVariableViewer *vv = GNOME_Development_VARIABLE_VIEWER (object);
     
     switch (arg_id) {
     case ARG_DEBUGGER :
@@ -454,7 +454,7 @@ add_dummy_child (GdfVariableViewer *vv, GtkCTreeNode *parent)
 }
 
 void
-add_node (GdfVariableViewer *vv, GtkCTreeNode *parent, GDF_Symbol *sym)
+add_node (GdfVariableViewer *vv, GtkCTreeNode *parent, GNOME_Development_Symbol *sym)
 {
     GtkCTreeNode *node;
     char *text[2];
@@ -487,7 +487,7 @@ clear_variable_viewer (GdfVariableViewer *vv)
 static void
 symbol_set_changed_cb (GdfSymbolSetClient *ss, GdfVariableViewer *vv)
 {
-    GDF_SymbolSequence *syms;
+    GNOME_Development_SymbolSequence *syms;
     int i;
 
     gdf_variable_viewer_clear (vv);
@@ -508,7 +508,7 @@ symbol_set_changed_cb (GdfSymbolSetClient *ss, GdfVariableViewer *vv)
 static void
 symbol_changed_cb (GdfSymbolSetClient *ss, int handle, GdfVariableViewer *vv)
 {
-    GDF_Symbol *sym;
+    GNOME_Development_Symbol *sym;
     GtkCTreeNode *node;
     GtkCTreeNode *child;
     GtkCTreeRow *row;
@@ -532,7 +532,7 @@ static void
 symbol_type_changed_cb (GdfSymbolSetClient *ss, int handle,
                         GdfVariableViewer *vv)
 {
-    GDF_Symbol *sym;
+    GNOME_Development_Symbol *sym;
     GtkCTreeNode *node;
     GtkCTreeNode *child;
     GtkCTreeRow *row;
@@ -627,19 +627,19 @@ add_current_expression (GdfVariableViewer *vv)
 void
 add_btn_clicked_cb (GtkWidget *btn, gpointer data)
 {
-    add_current_expression (GDF_VARIABLE_VIEWER (data));
+    add_current_expression (GNOME_Development_VARIABLE_VIEWER (data));
 }
 
 void
 entry_activate_cb (GtkWidget *editable, gpointer data)
 {
-    add_current_expression (GDF_VARIABLE_VIEWER (data));
+    add_current_expression (GNOME_Development_VARIABLE_VIEWER (data));
 }
 
 void
 tree_expand_cb (GtkWidget *ctree, GtkCTreeNode *node, gpointer data)
 {
-    GdfVariableViewer *vv = GDF_VARIABLE_VIEWER (data);
+    GdfVariableViewer *vv = GNOME_Development_VARIABLE_VIEWER (data);
     GtkCTreeNode *child;
     int sym_id;
 
@@ -653,7 +653,7 @@ tree_expand_cb (GtkWidget *ctree, GtkCTreeNode *node, gpointer data)
     /* if this is a dummy node, sym_id will be -1 */
     if (sym_id == -1) {
         int i;        
-        GDF_SymbolSequence *seq;
+        GNOME_Development_SymbolSequence *seq;
         sym_id = 
             GPOINTER_TO_INT (gtk_ctree_node_get_row_data (GTK_CTREE (ctree), 
                                                           node));
@@ -709,7 +709,7 @@ button_press_cb (GtkWidget *widget, GdkEventButton *event,
 {
 	gint row;
     int sym_id;
-    GDF_Symbol *sym;
+    GNOME_Development_Symbol *sym;
 
 	if (!gtk_clist_get_selection_info (GTK_CLIST (widget), 
 									   (gint)event->x, (gint)event->y,
@@ -721,7 +721,7 @@ button_press_cb (GtkWidget *widget, GdkEventButton *event,
 
     gdf_symbol_set_client_get_symbol (vv->priv->ss, sym_id, &sym);
 
-	if (sym->type != GDF_TYPE_ARRAY_SLICE && event->button == 3)
+	if (sym->type != GNOME_Development_TYPE_ARRAY_SLICE && event->button == 3)
 		do_popup (vv, sym_id);
 
     CORBA_free (sym);
@@ -734,7 +734,7 @@ set_value_selected_cb (GtkWidget *widget,
                        GdfVariableViewer *vv)
 {
     int sym_id;
-    GDF_Symbol *sym;
+    GNOME_Development_Symbol *sym;
     GtkWidget *dlg;
     GtkWidget *entry;
     GtkWidget *label;
@@ -807,7 +807,7 @@ cast_selected_cb (GtkWidget *widget,
                   GdfVariableViewer *vv)
 {
     int sym_id;
-    GDF_Symbol *sym;
+    GNOME_Development_Symbol *sym;
     GtkWidget *dlg;
     GtkWidget *entry;
     GtkWidget *label;
@@ -880,7 +880,7 @@ watchpoint_selected_cb (GtkWidget *widget,
                         GdfVariableViewer *vv)
 {
     int sym_id;
-    GDF_Symbol *sym;
+    GNOME_Development_Symbol *sym;
     GdfDebuggerClientResult res;
     
     sym_id = GPOINTER_TO_INT (gtk_object_get_data (GTK_OBJECT (vv), 
