@@ -21,20 +21,18 @@
  * Boston, MA 02111-1307, USA.  
  */
 
-#ifndef __GDF_H__
-#define __GDF_H__
+#ifndef __GNOME_Development_H__
+#define __GNOME_Development_H__
 
 #include <bonobo.h>
 #include "gnome-debug.h"
 
 BEGIN_GNOME_DECLS
 
-#include "gdf-tools.h"
+#include "gdf-breakpoint-set-client.h"
 #include "gdf-debugger-client.h"
 #include "gdf-dialogs.h"
-#include "gdf-event-channel-client.h"
 #include "gdf-event-marshallers.h"
-#include "gdf-server-manager.h"
 #include "gdf-symbol-set-client.h"
 
 END_GNOME_DECLS
